@@ -1,6 +1,8 @@
 import gpustat as gp
 import time, os
 import subprocess as sp
+import sys
+import importlib.util
 
 def monitor():
     c = gp.new_query()
@@ -11,16 +13,19 @@ def submit(job_text):
     # TODO: check correct env, but NOT part of the job_text
     # TODO: don't submit again after run once.
     tar_file = [ f for f in job_text.split(' ') if '.py' in f]
+    torch = importlib.util.find_spec('torch') is not None
     assert len(tar_file)==1
 
     while True:
         ppgpu = monitor()
         if sum(ppgpu)>1:
-            print(f'Still busy. File {tar_file[0]} is in local: {tar_file[0] in os.listdir()}.')
+            print(f'Still busy. File {tar_file[0]} is in local: {tar_file[0] in os.listdir()}. \
+            Torch present {torch}.')
         else:
             print('Done, submitting a new job!')
-            my_env = os.environ.copy()
-            sp.run(job_text, env=my_env)
+            # my_env = os.environ.copy()
+            sp.run(job_text)
             time.sleep(120)
+            sys.exit(0)
         time.sleep(1)
 
